@@ -1,5 +1,7 @@
 
 
+from typing import Union
+
 from pydantic import Field
 from pydantic import HttpUrl
 from pydantic import validator
@@ -8,6 +10,9 @@ from pydantic import create_model
 from tendril.utils.pydantic import TendrilTBaseModel
 
 
+UserReferenceTModel = Union[int, str]
+
+
 class UserStubTModel(TendrilTBaseModel):
     name: str = Field(..., example="User Full Name")
     nickname: str = Field(..., example="nickname")
